.. Crappy documentation master file, created by
   sphinx-quickstart on Wed Dec  9 11:03:38 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=======
CRAPPY
=======

This package aims to provide easy-to-use tools for command and acquisition on complex experimental setups.

.. toctree::

   whatiscrappy
   installation
   welcome
   tutorials
   documentation
   bugs
   license